import 'dart:typed_data';

/// BaaS@rakuzaにアップロードするファイルのMIMEタイプの定数です。
class MimeType {
  /// PNGファイル
  static const png = 'image/png';

  /// JPEGファイル
  static const jpeg = 'image/jpeg';

  /// GIFファイル
  static const gif = 'image/gif';

  /// MP4(ビデオ)ファイル
  static const mp4 = 'video/mp4';

  /// バイナリファイル
  ///
  /// 他の定数に一致するMIMEタイプがない場合はこの値を指定してください。
  static const binary = 'application/octet-stream';
}

/// BaaS@rakuzaにアップロードするファイルクラスです。
class RKZFile {
  /// ファイルデータ
  Uint8List? data;

  /// ファイル名
  String name;

  /// ファイルのMIMEタイプ。省略した場合は[MimeType.binary]になります。
  String mimeType;

  /// コンストラクタです。
  RKZFile({this.data, required this.name, this.mimeType = MimeType.binary});

  /// 空を表すファイルを返します。
  ///
  /// ファイルを削除する場合は、このメソッドの戻り値を登録してください。
  factory RKZFile.empty() {
    return RKZFile(data: null, name: '');
  }

  Map<String, dynamic> toMap() {
    return <String, dynamic>{
      '__type__': 'RKZFile',
      'data': data,
      'name': name,
      'mimeType': mimeType,
    };
  }
}
