import 'package:flutter/services.dart';

import '../models/beacon.dart';
import '../models/beacon_detect_contact.dart';
import '../models/spot.dart';
import '../platform_interface/beacon_query.dart';
import '../platform_interface/client.dart';
import '../utils/mappings.dart';
import 'method_channel_client.dart';

class MethodChannelBeaconQuery extends BeaconQueryPlatform
    with MethodChannelQuery {
  late MethodChannel _channel;

  MethodChannelBeaconQuery(MethodChannel channel) {
    _channel = channel;
  }

  @override
  Future<List<Beacon>> find() async {
    final data = await _channel.invokeListMethod<Map>('getBeaconList', {
      'searchConditions': exportSearchConditions(),
      'sortConditions': exportSortConditions()
    });
    return data!.map(importMap).map((data) => Beacon.fromMap(data!)).toList();
  }
}

class MethodChannelSpotQuery extends SpotQueryPlatform with MethodChannelQuery {
  late MethodChannel _channel;

  MethodChannelSpotQuery(MethodChannel channel) {
    _channel = channel;
  }

  @override
  Future<List<Spot>> find() async {
    final data = await _channel.invokeListMethod<Map>('getSpotList', {
      'searchConditions': exportSearchConditions(),
      'sortConditions': exportSortConditions()
    });
    return data!.map(importMap).map((data) => Spot.fromMap(data!)).toList();
  }
}

class MethodChannelBeaconContactQuery extends BeaconContactQueryPlatform
    with MethodChannelQuery {
  late MethodChannel _channel;
  String? _userAccessToken;

  MethodChannelBeaconContactQuery(
      MethodChannel channel, String userAccessToken) {
    _channel = channel;
    _userAccessToken = userAccessToken;
  }

  @override
  Future<List<BeaconDetectContact>> find() async {
    final data =
        await _channel.invokeListMethod<Map>('getDetectBeaconContact', {
      'userAccessToken': _userAccessToken,
      'searchConditions': exportSearchConditions(),
      'sortConditions': exportSortConditions()
    });
    return data!
        .map(importMap)
        .map((data) => BeaconDetectContact.fromMap(data!))
        .toList();
  }
}

mixin MethodChannelBeaconClient on RKZClientPlatform
    implements MethodChannelClientInterface {
  @override
  BeaconQueryPlatform beaconQuery() {
    return MethodChannelBeaconQuery(channel);
  }

  @override
  BeaconContactQueryPlatform beaconContactQuery(String userAccessToken) {
    return MethodChannelBeaconContactQuery(channel, userAccessToken);
  }

  @override
  SpotQueryPlatform spotQuery() {
    return MethodChannelSpotQuery(channel);
  }

  @override
  Future<void> addBeaconContact(String userAccessToken,
      {required DateTime contactDate,
      required String beaconId,
      String? beaconSpotCd,
      int? rssi,
      String? remarks}) async {
    return channel.invokeMethod('addDetectBeaconContact', {
      'userAccessToken': userAccessToken,
      'contactDate': exportDate(contactDate),
      'beaconId': beaconId,
      'beaconSpotCd': beaconSpotCd,
      'rssi': rssi,
      'remarks': remarks
    });
  }
}
