import 'package:flutter/services.dart';

import '../models/condition.dart';
import '../models/order.dart';
import '../platform_interface/client.dart';
import '../platform_interface/query.dart';
import 'method_channel_beacon_client.dart';
import 'method_channel_contact_client.dart';
import 'method_channel_coupon_client.dart';
import 'method_channel_data_client.dart';
import 'method_channel_news_client.dart';
import 'method_channel_point_client.dart';
import 'method_channel_stamp_client.dart';
import 'method_channel_system_client.dart';
import 'method_channel_user_client.dart';
import 'method_channel_user_detail_client.dart';

abstract class MethodChannelClientInterface {
  MethodChannel get channel;
}

mixin MethodChannelQuery implements QueryPlatform {
  final List<Condition> where = [];
  final List<Order> order = [];

  int? _offset;
  int? _limit;

  @override
  void equalTo(String columnName, String value) {
    where.add(Condition.equal(columnName: columnName, value: value));
  }

  @override
  void notEqualTo(String columnName, String value) {
    where.add(Condition.notEqualTo(columnName: columnName, value: value));
  }

  @override
  void containedIn(String columnName, List<String> values) {
    where.add(Condition.containedIn(columnName: columnName, values: values));
  }

  @override
  void notContainedIn(String columnName, List<String> values) {
    where.add(Condition.notContainedIn(columnName: columnName, values: values));
  }

  @override
  void lessThanOrEqualTo(String columnName, String value) {
    where
        .add(Condition.lessThanOrEqualTo(columnName: columnName, value: value));
  }

  @override
  void greaterThanOrEqualTo(String columnName, String value) {
    where.add(
        Condition.greaterThanOrEqualTo(columnName: columnName, value: value));
  }

  @override
  void betweenInclude(String columnName, String from, String to) {
    where.add(
        Condition.betweenInclude(columnName: columnName, from: from, to: to));
  }

  @override
  void betweenExclude(String columnName, String from, String to) {
    where.add(
        Condition.betweenExclude(columnName: columnName, from: from, to: to));
  }

  @override
  void startsWith(String columnName, String value) {
    where.add(Condition.startsWith(columnName: columnName, value: value));
  }

  @override
  void endsWith(String columnName, String value) {
    where.add(Condition.endsWith(columnName: columnName, value: value));
  }

  @override
  void contains(String columnName, String value) {
    where.add(Condition.contains(columnName: columnName, value: value));
  }

  @override
  void containsInArray(String columnName, List<String> values) {
    where
        .add(Condition.containsInArray(columnName: columnName, values: values));
  }

  @override
  void asc(String columnName) {
    order.add(Order.asc(columnName: columnName));
  }

  @override
  void desc(String columnName) {
    order.add(Order.desc(columnName: columnName));
  }

  @override
  int? get offset => _offset;

  @override
  set offset(int? offset) {
    _offset = offset;
  }

  @override
  int? get limit => _limit;

  @override
  set limit(int? limit) {
    _limit = limit;
  }

  List<Map<String, dynamic>> exportSearchConditions() {
    return where.map((condition) => condition.toMap()).toList();
  }

  List<Map<String, dynamic>> exportSortConditions() {
    return order.map((order) => order.toMap()).toList();
  }
}

class MethodChannelRKZClient extends RKZClientPlatform
    with
        MethodChannelBeaconClient,
        MethodChannelContactClient,
        MethodChannelCouponClient,
        MethodChannelDataClient,
        MethodChannelNewsClient,
        MethodChannelPointClient,
        MethodChannelStampClient,
        MethodChannelSystemClient,
        MethodChannelUserClient,
        MethodChannelUserDetailClient
    implements MethodChannelClientInterface {
  static const MethodChannel _channel = MethodChannel('baasatrakuza_flutter');

  @override
  MethodChannel get channel => _channel;
}
