import 'package:flutter/services.dart';

import '../models/contact.dart';
import '../platform_interface/client.dart';
import '../platform_interface/contact_query.dart';
import '../utils/mappings.dart';
import 'method_channel_client.dart';

class MethodChannelContactQuery extends ContactQueryPlatform
    with MethodChannelQuery {
  late MethodChannel _channel;
  String? _userAccessToken;

  MethodChannelContactQuery(MethodChannel channel, String userAccessToken) {
    _channel = channel;
    _userAccessToken = userAccessToken;
  }

  @override
  Future<List<Contact>> find() async {
    final data = await _channel.invokeListMethod<Map>('getContactList', {
      'userAccessToken': _userAccessToken,
      'searchConditions': exportSearchConditions(),
      'sortConditions': exportSortConditions()
    });
    return data!.map(importMap).map((data) => Contact.fromMap(data!)).toList();
  }
}

mixin MethodChannelContactClient on RKZClientPlatform
    implements MethodChannelClientInterface {
  @override
  ContactQueryPlatform contactQuery(String userAccessToken) {
    return MethodChannelContactQuery(channel, userAccessToken);
  }

  @override
  Future<void> addContact(String userAccessToken, Contact contact) async {
    return channel.invokeMethod('addContact',
        {'userAccessToken': userAccessToken, 'contact': contact.toMap()});
  }
}
