import 'package:flutter/services.dart';

import '../models/coupon.dart';
import '../models/my_coupon.dart';
import '../platform_interface/client.dart';
import '../platform_interface/coupon_query.dart';
import '../utils/mappings.dart';
import 'method_channel_client.dart';

class MethodChannelCouponQuery extends CouponQueryPlatform
    with MethodChannelQuery {
  late MethodChannel _channel;

  MethodChannelCouponQuery(MethodChannel channel) {
    _channel = channel;
  }

  @override
  Future<List<Coupon>> find() async {
    final data = await _channel.invokeListMethod<Map>('getCouponList', {
      'searchConditions': exportSearchConditions(),
      'sortConditions': exportSortConditions()
    });
    return data!.map(importMap).map((data) => Coupon.fromMap(data!)).toList();
  }
}

class MethodChannelMyCouponQuery extends MyCouponQueryPlatform
    with MethodChannelQuery {
  late MethodChannel _channel;
  String? _userAccessToken;

  MethodChannelMyCouponQuery(MethodChannel channel, String userAccessToken) {
    _channel = channel;
    _userAccessToken = userAccessToken;
  }

  @override
  Future<List<MyCoupon>> find() async {
    final data = await _channel.invokeListMethod<Map>('getMyCouponList', {
      'userAccessToken': _userAccessToken,
      'searchConditions': exportSearchConditions(),
      'sortConditions': exportSortConditions()
    });
    return data!.map(importMap).map((data) => MyCoupon.fromMap(data!)).toList();
  }
}

mixin MethodChannelCouponClient on RKZClientPlatform
    implements MethodChannelClientInterface {
  @override
  CouponQueryPlatform couponQuery() {
    return MethodChannelCouponQuery(channel);
  }

  @override
  Future<Coupon> getCoupon(String code) async {
    final data = await channel
        .invokeMapMethod<String, dynamic>('getCoupon', {'code': code});
    return Coupon.fromMap(data!);
  }

  @override
  Future<void> exchangeCoupon(
      String userAccessToken, String code, int quantity) async {
    return channel.invokeMethod('exchangeCoupon', {
      'userAccessToken': userAccessToken,
      'code': code,
      'quantity': quantity
    });
  }

  @override
  MyCouponQueryPlatform myCouponQuery(String userAccessToken) {
    return MethodChannelMyCouponQuery(channel, userAccessToken);
  }

  @override
  Future<MyCoupon> getMyCoupon(
      String userAccessToken, String myCouponCd) async {
    final data = await channel.invokeMapMethod<String, dynamic>('getMyCoupon',
        {'userAccessToken': userAccessToken, 'myCouponCd': myCouponCd});
    return MyCoupon.fromMap(data!);
  }

  @override
  Future<void> useMyCoupon(
      String userAccessToken, String myCouponCd, String couponCd) async {
    return channel.invokeMethod('useMyCoupon', {
      'userAccessToken': userAccessToken,
      'myCouponCd': myCouponCd,
      'couponCd': couponCd
    });
  }
}
