import 'package:flutter/services.dart';

import '../models/app_settings.dart';
import '../models/locale.dart';
import '../platform_interface/client.dart';
import '../platform_interface/locale_query.dart';
import '../utils/mappings.dart';
import 'method_channel_client.dart';

class MethodChannelLocaleQuery extends LocaleQueryPlatform
    with MethodChannelQuery {
  late MethodChannel _channel;

  MethodChannelLocaleQuery(MethodChannel channel) {
    _channel = channel;
  }

  @override
  Future<List<Locale>> find() async {
    final data = await _channel.invokeListMethod<Map>('getLocaleList', {
      'searchConditions': exportSearchConditions(),
      'sortConditions': exportSortConditions()
    });
    return data!.map(importMap).map((data) => Locale.fromMap(data!)).toList();
  }
}

mixin MethodChannelSystemClient on RKZClientPlatform
    implements MethodChannelClientInterface {
  @override
  Future<void> init(String tenantKey) async {
    return channel.invokeMethod('setTenantKey', {'tenantKey': tenantKey});
  }

  @override
  Future<bool> isInitialized() async {
    return (await channel.invokeMethod<bool>('isInitialized'))!;
  }

  @override
  Future<void> setDefaultTimeout(int timeout) {
    return channel.invokeMethod('setDefaultTimeout', {'timeout': timeout});
  }

  @override
  Future<DateTime> now() async {
    final now = await channel.invokeMethod<int>('getSystemDate');
    return importDate(now)!;
  }

  @override
  Future<AppSettings> appSettings() async {
    final data = await channel
        .invokeMapMethod<String, dynamic>('getApplicationSettingData');
    return AppSettings.fromMap(data!);
  }

  @override
  LocaleQueryPlatform localeQuery() {
    return MethodChannelLocaleQuery(channel);
  }

  @override
  Future<String> setMyLocale(String userAccessToken, String locale) async {
    return (await channel.invokeMethod<String>(
        'setLocale', {'userAccessToken': userAccessToken, 'locale': locale}))!;
  }

  @override
  Future<String> getLocale() async {
    return (await channel.invokeMethod<String>('getLocale'))!;
  }
}
