import '../models/field.dart';
import '../models/model_change_result.dart';
import '../models/user.dart';
import '../platform_interface/client.dart';
import '../types.dart';
import '../utils/mappings.dart';
import 'method_channel_client.dart';

mixin MethodChannelUserClient on RKZClientPlatform
    implements MethodChannelClientInterface {
  @override
  Future<User> registerUser(User user) async {
    final userMap = await channel
        .invokeMapMethod<String, dynamic>('registUser', {'user': user.toMap()});
    return User.fromMap(userMap!);
  }

  @override
  Future<User> getUser(String userAccessToken) async {
    final userMap = await channel.invokeMapMethod<String, dynamic>(
        'getUser', {'userAccessToken': userAccessToken});
    return User.fromMap(userMap!);
  }

  @override
  Future<User> editUser(User user) async {
    final userMap = await channel
        .invokeMapMethod<String, dynamic>('editUser', {'user': user.toMap()});
    return User.fromMap(userMap!);
  }

  @override
  Future<void> editPassword(
      String userAccessToken, String nowPassword, String newPassword) {
    return channel.invokeMethod('editPassword', {
      'userAccessToken': userAccessToken,
      'nowPassword': nowPassword,
      'newPassword': newPassword
    });
  }

  @override
  Future<ModelChangeResult> issueModelChangeCode(String userAccessToken,
      {String? password, int? limitCode, int? limitMinute}) async {
    final modelChangeResult = await channel
        .invokeMapMethod<String, dynamic>('registModelChangeCode', {
      'userAccessToken': userAccessToken,
      'password': password,
      'limitCode': limitCode,
      'limitMinute': limitMinute
    });
    return ModelChangeResult.fromMap(modelChangeResult!);
  }

  @override
  Future<User> authWithModelChangeCode(String modelChangeCode,
      {String? password}) async {
    final userMap = await channel.invokeMapMethod<String, dynamic>(
        'authModelChange',
        {'modelChangeCode': modelChangeCode, 'password': password});
    return User.fromMap(userMap!);
  }

  @override
  Future<User> auth(String loginId, String password) async {
    final userMap = await channel.invokeMapMethod<String, dynamic>(
        'userAuth', {'loginId': loginId, 'password': password});
    return User.fromMap(userMap!);
  }

  @override
  Future<String> updateToken(String userAccessToken) async {
    return (await channel.invokeMethod<String>(
        'updateUserAccessToken', {'userAccessToken': userAccessToken}))!;
  }

  @override
  Future<String> beginTokenUpdate(String userAccessToken) async {
    return (await channel.invokeMethod<String>(
        'beginUpdateUserAccessToken', {'userAccessToken': userAccessToken}))!;
  }

  @override
  Future<String> commitTokenUpdate(String userAccessToken) async {
    return (await channel.invokeMethod<String>(
        'commitUpdateUserAccessToken', {'userAccessToken': userAccessToken}))!;
  }

  @override
  Future<List<Field>> getUserFields({bool? visibleOnly = true}) async {
    final data = await channel.invokeListMethod<Map>(
        'getUserFieldDataList', {'visibleOnly': visibleOnly});
    return data!.map(importMap).map((data) => Field.fromMap(data!)).toList();
  }

  @override
  Future<void> registerPushDeviceToken(
      String userAccessToken, String deviceToken,
      {DeviceType? deviceType}) {
    return channel.invokeMethod('registPushDeviceToken',
        {'userAccessToken': userAccessToken, 'deviceToken': deviceToken});
  }

  @override
  Future<void> clearPushDeviceToken(String userAccessToken) {
    return channel.invokeMethod(
        'clearPushDeviceToken', {'userAccessToken': userAccessToken});
  }
}
