/// 検索条件値の型です。
class Condition {
  /// 演算子
  late String operator;

  /// 項目名称
  late String columnName;

  /// 条件値
  late List<String> values;

  /// コンストラクタです。
  Condition(
      {required this.operator, required this.columnName, required this.values});

  /// 一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[value]に条件値を指定してください。
  Condition.equal({required this.columnName, required String value}) {
    operator = 'equal';
    values = [value];
  }

  /// 不一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[value]に条件値を指定してください。
  Condition.notEqualTo({required this.columnName, required String value}) {
    operator = 'not_equal';
    values = [value];
  }

  /// 要素リスト一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[values]に条件値を指定してください。
  Condition.containedIn({required this.columnName, required this.values}) {
    operator = 'in';
  }

  /// 要素リスト不一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[values]に条件値を指定してください。
  Condition.notContainedIn({required this.columnName, required this.values}) {
    operator = 'not_in';
  }

  /// 条件値以下の検索条件を追加します。
  ///
  /// [columnName]に項目名称、[value]に条件値を指定してください。
  Condition.lessThanOrEqualTo(
      {required this.columnName, required String value}) {
    operator = 'less_than_include';
    values = [value];
  }

  /// 条件値以上の検索条件を追加します。
  ///
  /// [columnName]に項目名称、[value]に条件値を指定してください。
  Condition.greaterThanOrEqualTo(
      {required this.columnName, required String value}) {
    operator = 'greater_than_include';
    values = [value];
  }

  /// 範囲検索条件の検索条件を追加します。
  ///
  /// [columnName]に項目名称、[from]に範囲指定最小値、[to]に範囲指定最大値を指定してください。
  ///
  /// **NOTE:** 条件値を含んだ範囲検索条件が設定されます。
  Condition.betweenInclude(
      {required this.columnName, required String from, required String to}) {
    operator = 'between_include';
    values = [from, to];
  }

  /// 範囲検索条件の検索条件を追加します。
  ///
  /// [columnName]に項目名称、[from]に範囲指定最小値、[to]に範囲指定最大値を指定してください。
  ///
  /// **NOTE:** 条件値を含まない範囲検索条件が設定されます。
  Condition.betweenExclude(
      {required this.columnName, required String from, required String to}) {
    operator = 'between_exclude';
    values = [from, to];
  }

  /// テキストの前方一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[value]に条件値を指定してください。
  Condition.startsWith({required this.columnName, required String value}) {
    operator = 'like_before';
    values = [value];
  }

  /// テキストの後方一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[value]に条件値を指定してください。
  Condition.endsWith({required this.columnName, required String value}) {
    operator = 'like_after';
    values = [value];
  }

  /// テキストの中間一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[value]に条件値を指定してください。
  Condition.contains({required this.columnName, required String value}) {
    operator = 'like_both';
    values = [value];
  }

  /// チェックボックス項目の要素リスト一致検索条件を追加します。
  ///
  /// [columnName]に項目名称、[values]に条件値を指定してください。
  ///
  /// **NOTE:** 表示タイプにチェックボックスを指定した項目専用です。その他の表示タイプでは使用しないでください。
  Condition.containsInArray({required this.columnName, required this.values}) {
    operator = 'like_or';
  }

  Map<String, dynamic> toMap() {
    return <String, dynamic>{
      'operator': operator,
      'columnName': columnName,
      'values': values
    };
  }
}
