import '../utils/mappings.dart';
import 'attributable.dart';

/// クーポン情報。
class Coupon with Attributable {
  /// コード
  String? code;

  /// 使用可能期間：開始
  DateTime? enableFromDte;

  /// 使用可能期間：終了
  DateTime? enableToDte;

  /// 画像(URL)
  String? imageUrl;

  /// 画像
  String? image;

  /// クーポン名称
  String? name;

  /// 使用不可フラグ
  bool? notUseFlg;

  /// クーポン交換ポイント
  int? point;

  /// 取得可能期間：開始
  DateTime? possibleFromDte;

  /// 取得可能期間：終了
  DateTime? possibleToDte;

  /// 順序
  int? sortNo;

  Coupon();

  factory Coupon.fromMap(Map<String, dynamic> map) {
    final data = Coupon();

    data.code = map['code'] as String?;
    data.enableFromDte = importDate(map['enableFromDte'] as int?);
    data.enableToDte = importDate(map['enableToDte'] as int?);
    data.imageUrl = map['imageUrl'] as String?;
    data.image = map['image'] as String?;
    data.name = map['name'] as String?;
    data.notUseFlg = map['notUseFlg'] as bool?;
    data.point = map['point'] as int?;
    data.possibleFromDte = importDate(map['possibleFromDte'] as int?);
    data.possibleToDte = importDate(map['possibleToDte'] as int?);
    data.sortNo = map['sortNo'] as int?;
    data.attributes = importMap(map['attributes'] as Map?);

    return data;
  }

  static Coupon? import(Map<String, dynamic>? map) {
    if (map == null) return null;
    return Coupon.fromMap(map);
  }

  Map<String, dynamic> toMap() {
    final map = <String, dynamic>{};

    map['code'] = code;
    map['enableFromDte'] = exportDate(enableFromDte);
    map['enableToDte'] = exportDate(enableToDte);
    map['imageUrl'] = imageUrl;
    map['image'] = image;
    map['name'] = name;
    map['notUseFlg'] = notUseFlg;
    map['point'] = point;
    map['possibleFromDte'] = exportDate(possibleFromDte);
    map['possibleToDte'] = exportDate(possibleToDte);
    map['sortNo'] = sortNo;
    map['attributes'] = exportAttributes(attributes);

    return map;
  }
}
