import '../utils/mappings.dart';
import 'attributable.dart';
import 'favorite.dart';
import 'favorite_summary.dart';

/// オブジェクトデータです。
class Data with Attributable {
  /// コード
  String? code;

  /// 名称
  String? name;

  /// 使用不可フラグ
  bool? notUseFlg;

  /// オブジェクトID
  String? objectId;

  /// 短縮名称
  String? shortName;

  /// 順序
  int? sortNo;

  /// お気に入り集計情報
  FavoriteSummary? sysFavoriteSum;

  /// お気に入り情報
  Favorite? sysFavorite;

  /// 登録日時
  DateTime? sysInsertDate;

  /// 更新日時
  DateTime? sysUpdateDate;

  Data();

  factory Data.fromMap(Map<String, dynamic> map) {
    final data = Data();

    data.code = map['code'] as String?;
    data.name = map['name'] as String?;
    data.notUseFlg = map['notUseFlg'] as bool?;
    data.objectId = map['objectId'] as String?;
    data.shortName = map['shortName'] as String?;
    data.sortNo = map['sortNo'] as int?;
    data.sysFavoriteSum =
        FavoriteSummary.import(importMap(map['sysFavoriteSum'] as Map?));
    data.sysFavorite = Favorite.import(importMap(map['sysFavorite'] as Map?));
    data.sysInsertDate = importDate(map['sysInsertDate'] as int?);
    data.sysUpdateDate = importDate(map['sysUpdateDate'] as int?);
    data.attributes = importMap(map['attributes'] as Map?);

    return data;
  }

  static Data? import(Map<String, dynamic>? map) {
    if (map == null) return null;
    return Data.fromMap(map);
  }

  Map<String, dynamic> toMap() {
    final map = <String, dynamic>{};

    map['code'] = code;
    map['name'] = name;
    map['notUseFlg'] = notUseFlg;
    map['objectId'] = objectId;
    map['shortName'] = shortName;
    map['sortNo'] = sortNo;
    map['sysFavoriteSum'] = sysFavoriteSum?.toMap();
    map['sysFavorite'] = sysFavorite?.toMap();
    map['sysInsertDate'] = exportDate(sysInsertDate);
    map['sysUpdateDate'] = exportDate(sysUpdateDate);
    map['attributes'] = exportAttributes(attributes);

    return map;
  }
}
