import '../utils/mappings.dart';
import 'attributable.dart';

/// フィールド情報。
///
/// [Attributable.attributes]に格納される値については[フィールド情報のattributesについて](https://github.com/pscsrv/cordova-plugin-baasatrakuza/wiki/Objects#%E3%83%95%E3%82%A3%E3%83%BC%E3%83%AB%E3%83%89%E6%83%85%E5%A0%B1%E3%82%AA%E3%83%96%E3%82%B8%E3%82%A7%E3%82%AF%E3%83%88%E3%81%AEattributes%E3%81%AB%E3%81%A4%E3%81%84%E3%81%A6)を参照してください。
///
class Field with Attributable {
  /// データタイプID
  String? dataTypeId;

  /// オブジェクト項目の表示タイプに指定した値に該当するID
  ///
  /// 表示タイプに該当するIDは[表示タイプ](https://github.com/pscsrv/cordova-plugin-baasatrakuza/wiki/Objects#%E8%A1%A8%E7%A4%BA%E3%82%BF%E3%82%A4%E3%83%97%E3%81%AB%E3%81%A4%E3%81%84%E3%81%A6)を参照してください。
  String? displayType;

  /// オブジェクト項目の項目名称
  String? fieldName;

  /// ヘルプテキスト
  String? helpTxt;

  /// オブジェクト項目の必須入力フラグ
  bool? isRequiredFlg;

  /// オブジェクト項目の表示項目名称
  String? labelStr;

  /// 最大文字数
  int? maxLength;

  /// 最小文字数
  int? minLength;

  /// 非表示フラグ
  bool? notVisibleFlg;

  /// オブジェクト項目の読取り専用フラグ
  bool? readOnlyFlg;

  /// 項目の表示順
  int? sortNo;

  Field();

  factory Field.fromMap(Map<String, dynamic> map) {
    final data = Field();

    data.dataTypeId = map['dataTypeId'] as String?;
    data.displayType = map['displayType'] as String?;
    data.fieldName = map['fieldName'] as String?;
    data.helpTxt = map['helpTxt'] as String?;
    data.isRequiredFlg = map['isRequiredFlg'] as bool?;
    data.labelStr = map['labelStr'] as String?;
    data.maxLength =
        (map['maxLength'] as num?)?.toInt(); // Androidはdoubleで返ってくる
    data.minLength =
        (map['minLength'] as num?)?.toInt(); // Androidはdoubleで返ってくる
    data.notVisibleFlg = map['notVisibleFlg'] as bool?;
    data.readOnlyFlg =
        importBool(map['readOnlyFlg'] as String?); // Stringで返ってくる
    data.sortNo = map['sortNo'] as int?;
    data.attributes = importMap(map['attributes'] as Map?);

    return data;
  }

  Map<String, dynamic> toMap() {
    final map = <String, dynamic>{};

    map['dataTypeId'] = dataTypeId;
    map['displayType'] = displayType;
    map['fieldName'] = fieldName;
    map['helpTxt'] = helpTxt;
    map['isRequiredFlg'] = isRequiredFlg;
    map['labelStr'] = labelStr;
    map['maxLength'] = maxLength;
    map['minLength'] = minLength;
    map['notVisibleFlg'] = notVisibleFlg;
    map['readOnlyFlg'] = readOnlyFlg;
    map['sortNo'] = sortNo;
    map['attributes'] = exportAttributes(attributes);

    return map;
  }
}
