import '../utils/mappings.dart';
import 'attributable.dart';

/// お知らせ情報。
class News with Attributable {
  /// 発信者
  String? author;

  /// カテゴリ名称
  String? categoryName;

  /// カテゴリコード
  String? category;

  /// 作成日付
  DateTime? date;

  /// 内容
  String? description;

  /// お気に入り件数
  int? favoriteCount;

  /// お気に入り更新日時
  DateTime? favoriteDate;

  /// ジャンル名称
  String? genreName;

  /// ジャンルコード
  String? genre;

  /// ユーザー自身がお気に入り登録している場合`true`
  bool? isFavorite;

  /// 配信条件一致フラグ
  bool? matchSegmentFlg;

  /// お知らせID
  String? newsId;

  /// 配信状況情報
  Map<String, dynamic>? newsSegmentConditions;

  /// 画像URL
  String? photo;

  /// プッシュ通知済みフラグ
  bool? pushDoneFlg;

  /// プッシュ通知予約日時
  DateTime? pushTime;

  /// 既読日時
  DateTime? readedDte;

  /// 既読の場合`true`
  bool? readedFlg;

  /// 公開終了日時
  DateTime? releaseEndDate;

  /// 公開フラグ
  bool? releaseFlg;

  /// 公開開始日時
  DateTime? releaseFromDate;

  /// 公開対象者区分名称
  String? releaseTargetKbnName;

  /// 公開対象者区分
  String? releaseTargetKbn;

  /// RSS出力フラグ
  bool? rssFlg;

  /// テナントID
  String? tenantId;

  /// タイトル
  String? title;

  /// 詳細URL
  String? url;

  /// プッシュ配信利用フラグ
  bool? usePushFlg;

  News();

  factory News.fromMap(Map<String, dynamic> map) {
    final data = News();

    data.author = map['author'] as String?;
    data.categoryName = map['categoryName'] as String?;
    data.category = map['category'] as String?;
    data.date = importDate(map['date'] as int?);
    data.description = map['description'] as String?;
    data.favoriteCount = map['favoriteCount'] as int?;
    data.favoriteDate = importDate(map['favoriteDate'] as int?);
    data.genreName = map['genreName'] as String?;
    data.genre = map['genre'] as String?;
    data.isFavorite = map['isFavorite'] as bool?;
    data.matchSegmentFlg = map['matchSegmentFlg'] as bool?;
    data.newsId = map['newsId'] as String?;
    data.newsSegmentConditions =
        importMap(map['newsSegmentConditions'] as Map?);
    data.photo = map['photo'] as String?;
    data.pushDoneFlg = map['pushDoneFlg'] as bool?;
    data.pushTime = importDate(map['pushTime'] as int?);
    data.readedDte = importDate(map['readedDte'] as int?);
    data.readedFlg = map['readedFlg'] as bool?;
    data.releaseEndDate = importDate(map['releaseEndDate'] as int?);
    data.releaseFlg = map['releaseFlg'] as bool?;
    data.releaseFromDate = importDate(map['releaseFromDate'] as int?);
    data.releaseTargetKbnName = map['releaseTargetKbnName'] as String?;
    data.releaseTargetKbn = map['releaseTargetKbn'] as String?;
    data.rssFlg = map['rssFlg'] as bool?;
    data.tenantId = map['tenantId'] as String?;
    data.title = map['title'] as String?;
    data.url = map['url'] as String?;
    data.usePushFlg = map['usePushFlg'] as bool?;
    data.attributes = importMap(map['attributes'] as Map?);

    return data;
  }

  Map<String, dynamic> toMap() {
    final map = <String, dynamic>{};

    map['author'] = author;
    map['categoryName'] = categoryName;
    map['category'] = category;
    map['date'] = exportDate(date);
    map['description'] = description;
    map['favoriteCount'] = favoriteCount;
    map['favoriteDate'] = exportDate(favoriteDate);
    map['genreName'] = genreName;
    map['genre'] = genre;
    map['isFavorite'] = isFavorite;
    map['matchSegmentFlg'] = matchSegmentFlg;
    map['newsId'] = newsId;
    map['newsSegmentConditions'] = newsSegmentConditions;
    map['photo'] = photo;
    map['pushDoneFlg'] = pushDoneFlg;
    map['pushTime'] = exportDate(pushTime);
    map['readedDte'] = exportDate(readedDte);
    map['readedFlg'] = readedFlg;
    map['releaseEndDate'] = exportDate(releaseEndDate);
    map['releaseFlg'] = releaseFlg;
    map['releaseFromDate'] = exportDate(releaseFromDate);
    map['releaseTargetKbnName'] = releaseTargetKbnName;
    map['releaseTargetKbn'] = releaseTargetKbn;
    map['rssFlg'] = rssFlg;
    map['tenantId'] = tenantId;
    map['title'] = title;
    map['url'] = url;
    map['usePushFlg'] = usePushFlg;
    map['attributes'] = exportAttributes(attributes);

    return map;
  }
}
