import '../utils/mappings.dart';

/// ソート順の方向です。
enum Direction {
  /// 昇順
  asc,

  /// 降順
  desc,
}

extension DirectionExtensions on Direction {
  /// テキストに変換します。
  String? toStringValue() {
    switch (this) {
      case Direction.asc:
        return '0001';
      case Direction.desc:
        return '0002';
      default:
        return null;
    }
  }
}

/// ソート条件のクラスです。
class Order {
  /// ソート順の方向です。
  late Direction direction;

  /// 項目名称
  late String columnName;

  /// コンストラクタです。
  Order({required this.direction, required this.columnName});

  /// 昇順のソート条件を追加します。
  Order.asc({required this.columnName}) {
    direction = Direction.asc;
  }

  /// 降順のソート条件を追加します。
  Order.desc({required this.columnName}) {
    direction = Direction.desc;
  }

  Map<String, dynamic> toMap() {
    return <String, dynamic>{
      'direction': exportDirection(direction),
      'columnName': columnName
    };
  }
}
