import '../utils/mappings.dart';
import 'attributable.dart';

/// スポット情報。
class Spot with Attributable {
  /// ビーコン検知範囲（Android用）
  int? beaconRangeForAndroid;

  /// ビーコン検知範囲（iOS用）
  int? beaconRangeForIphone;

  /// 設置ビーコン端末
  List<String>? beacon;

  /// コード
  String? code;

  /// 緯度
  String? latitude;

  /// 経度
  String? longitude;

  /// スポット名称
  String? name;

  /// 使用不可フラグ
  bool? notUseFlg;

  /// ピクセル位置X
  String? pixelPositionX;

  /// ピクセル位置Y
  String? pixelPositionY;

  /// 短縮名称
  String? shortName;

  /// 順序
  int? sortNo;

  Spot();

  factory Spot.fromMap(Map<String, dynamic> map) {
    final data = Spot();

    data.beaconRangeForAndroid = map['beaconRangeForAndroid'] as int?;
    data.beaconRangeForIphone = map['beaconRangeForIphone'] as int?;
    data.beacon = importStringList(map['beacon'] as List<dynamic>?);
    data.code = map['code'] as String?;
    data.latitude = map['latitude'] as String?;
    data.longitude = map['longitude'] as String?;
    data.name = map['name'] as String?;
    data.notUseFlg = map['notUseFlg'] as bool?;
    data.pixelPositionX = map['pixelPositionX'] as String?;
    data.pixelPositionY = map['pixelPositionY'] as String?;
    data.shortName = map['shortName'] as String?;
    data.sortNo = map['sortNo'] as int?;
    data.attributes = importMap(map['attributes'] as Map?);

    return data;
  }

  static Spot? import(Map<String, dynamic>? map) {
    if (map == null) return null;
    return Spot.fromMap(map);
  }

  Map<String, dynamic> toMap() {
    final map = <String, dynamic>{};

    map['beaconRangeForAndroid'] = beaconRangeForAndroid;
    map['beaconRangeForIphone'] = beaconRangeForIphone;
    map['beacon'] = beacon;
    map['code'] = code;
    map['latitude'] = latitude;
    map['longitude'] = longitude;
    map['name'] = name;
    map['notUseFlg'] = notUseFlg;
    map['pixelPositionX'] = pixelPositionX;
    map['pixelPositionY'] = pixelPositionY;
    map['shortName'] = shortName;
    map['sortNo'] = sortNo;
    map['attributes'] = exportAttributes(attributes);

    return map;
  }
}
