import '../types.dart';
import '../utils/mappings.dart';
import 'attributable.dart';
import 'favorite.dart';
import 'favorite_summary.dart';

/// ユーザー詳細です。
class UserDetail with Attributable {
  /// コード
  String? code;

  /// ユーザー詳細ID
  String? id;

  /// オブジェクトID
  String? objectId;

  /// 並び順(オブジェクト別)
  int? objectSortNo;

  /// 順序
  int? sortNo;

  /// お気に入り集計情報
  FavoriteSummary? sysFavoriteSum;

  /// お気に入り情報
  Favorite? sysFavorite;

  /// 登録日時
  DateTime? sysInsertDate;

  /// 更新日時
  DateTime? sysUpdateDate;

  /// ユーザーID
  String? userId;

  /// 顧客番号
  String? userNo;

  /// ユーザーテナントID
  String? userTenantId;

  /// 公開範囲
  VisibilityType? visibility;

  UserDetail();

  factory UserDetail.fromMap(Map<String, dynamic> map) {
    final data = UserDetail();

    data.code = map['code'] as String?;
    data.id = map['id'] as String?;
    data.objectId = map['objectId'] as String?;
    data.objectSortNo = map['objectSortNo'] as int?;
    data.sortNo = map['sortNo'] as int?;
    data.sysFavoriteSum =
        FavoriteSummary.import(importMap(map['sysFavoriteSum'] as Map?));
    data.sysFavorite = Favorite.import(importMap(map['sysFavorite'] as Map?));
    data.sysInsertDate = importDate(map['sysInsertDate'] as int?);
    data.sysUpdateDate = importDate(map['sysUpdateDate'] as int?);
    data.userId = map['userId'] as String?;
    data.userNo = map['userNo'] as String?;
    data.userTenantId = map['userTenantId'] as String?;
    data.visibility = importVisibility(map['visibility'] as String?);
    data.attributes = importMap(map['attributes'] as Map?);

    return data;
  }

  Map<String, dynamic> toMap() {
    final map = <String, dynamic>{};

    map['code'] = code;
    map['id'] = id;
    map['objectId'] = objectId;
    map['objectSortNo'] = objectSortNo;
    map['sortNo'] = sortNo;
    map['sysFavoriteSum'] = sysFavoriteSum?.toMap();
    map['sysFavorite'] = sysFavorite?.toMap();
    map['sysInsertDate'] = exportDate(sysInsertDate);
    map['sysUpdateDate'] = exportDate(sysUpdateDate);
    map['userId'] = userId;
    map['userNo'] = userNo;
    map['userTenantId'] = userTenantId;
    map['visibility'] = visibility?.toStringValue();
    map['attributes'] = exportAttributes(attributes);

    return map;
  }
}
