import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import '../method_channel/method_channel_client.dart';
import '../models/app_settings.dart';
import '../models/contact.dart';
import '../models/coupon.dart';
import '../models/data.dart';
import '../models/field.dart';
import '../models/location.dart';
import '../models/model_change_result.dart';
import '../models/my_coupon.dart';
import '../models/news.dart';
import '../models/point.dart';
import '../models/user.dart';
import '../models/user_detail.dart';
import '../platform_interface/locale_query.dart';
import '../types.dart';
import 'beacon_query.dart';
import 'contact_query.dart';
import 'coupon_query.dart';
import 'data_query.dart';
import 'news_query.dart';
import 'stamp_query.dart';
import 'user_detail_query.dart';

abstract class RKZClientPlatform extends PlatformInterface {
  RKZClientPlatform() : super(token: _token);

  static final Object _token = Object();

  static RKZClientPlatform _instance = MethodChannelRKZClient();

  static RKZClientPlatform get instance => _instance;

  static set instance(RKZClientPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  // System Client

  Future<void> init(String tenantKey) async {
    throw UnimplementedError('init() is not implemented');
  }

  Future<bool> isInitialized() async {
    throw UnimplementedError('isInitialized() is not implemented');
  }

  Future<void> setDefaultTimeout(int timeout) async {
    throw UnimplementedError('setDefaultTimeout() is not implemented');
  }

  Future<DateTime> now() async {
    throw UnimplementedError('now() is not implemented');
  }

  Future<AppSettings> appSettings() async {
    throw UnimplementedError('appSettings() is not implemented');
  }

  LocaleQueryPlatform localeQuery() {
    throw UnimplementedError('localeQuery() is not implemented');
  }

  Future<String> setMyLocale(String userAccessToken, String locale) {
    throw UnimplementedError('setMyLocale() is not implemented');
  }

  Future<String> getLocale() {
    throw UnimplementedError('getLocale() is not implemented');
  }

  // Data Client

  DataQueryPlatform dataQuery(String objectId, {String? userAccessToken}) {
    throw UnimplementedError('dataQuery() is not implemented');
  }

  Future<Data> getData(String objectId, String code) async {
    throw UnimplementedError('getData() is not implemented');
  }

  Future<Data> getDataWithRelation(String objectId, String code,
      {int? treeCount}) async {
    throw UnimplementedError('getDataWithRelation() is not implemented');
  }

  Future<Data> getDataByLocation(String objectId, String code,
      {RKZLocation? location, String? spotFieldName}) async {
    throw UnimplementedError('getDataByLocation() is not implemented');
  }

  Future<void> addData(Data data) async {
    throw UnimplementedError('addData() is not implemented');
  }

  Future<void> editData(Data data) async {
    throw UnimplementedError('editData() is not implemented');
  }

  Future<List<Field>> getDataFields(String objectId,
      {bool? visibleOnly = true}) async {
    throw UnimplementedError('getDataFields() is not implemented');
  }

  Future<Data> getDataByQRCode(String qrCode) async {
    throw UnimplementedError('getByQRCode() is not implemented');
  }

  Future<void> addDataToFavorite(
      String userAccessToken, String objectId, String code) async {
    throw UnimplementedError('addDataToFavorite() is not implemented');
  }

  Future<void> deleteDataFromFavorite(
      String userAccessToken, String objectId, String code) async {
    throw UnimplementedError('deleteDataFromFavorite() is not implemented');
  }

  // User Client

  Future<User> registerUser(User user) async {
    throw UnimplementedError('register() is not implemented');
  }

  Future<User> getUser(String userAccessToken) async {
    throw UnimplementedError('getUser() is not implemented');
  }

  Future<User> editUser(User user) async {
    throw UnimplementedError('editUser() is not implemented');
  }

  Future<void> editPassword(
      String userAccessToken, String nowPassword, String newPassword) async {
    throw UnimplementedError('editPassword() is not implemented');
  }

  Future<ModelChangeResult> issueModelChangeCode(String userAccessToken,
      {String? password, int? limitCode, int? limitMinute}) async {
    throw UnimplementedError('issueModelChangeCode() is not implemented');
  }

  Future<User> authWithModelChangeCode(String modelChangeCode,
      {String? password}) async {
    throw UnimplementedError('authWithModelChangeCode() is not implemented');
  }

  Future<User> auth(String loginId, String password) async {
    throw UnimplementedError('auth() is not implemented');
  }

  Future<String> updateToken(String userAccessToken) async {
    throw UnimplementedError('updateToken() is not implemented');
  }

  Future<String> beginTokenUpdate(String userAccessToken) async {
    throw UnimplementedError('beginTokenUpdate() is not implemented');
  }

  Future<String> commitTokenUpdate(String userAccessToken) async {
    throw UnimplementedError('commitTokenUpdate() is not implemented');
  }

  Future<List<Field>> getUserFields({bool? visibleOnly = true}) async {
    throw UnimplementedError('getUserFields() is not implemented');
  }

  Future<void> registerPushDeviceToken(
      String userAccessToken, String deviceToken,
      {DeviceType? deviceType}) async {
    throw UnimplementedError('registerPushDeviceToken() is not implemented');
  }

  Future<void> clearPushDeviceToken(String userAccessToken) async {
    throw UnimplementedError('clearPushDeviceToken() is not implemented');
  }

  // Contact Client

  ContactQueryPlatform contactQuery(String userAccessToken) {
    throw UnimplementedError('contactQuery() is not implemented');
  }

  Future<void> addContact(String userAccessToken, Contact contact) async {
    throw UnimplementedError('addContact() is not implemented');
  }

  // News Client

  NewsQueryPlatform newsQuery({String? userAccessToken}) {
    throw UnimplementedError('newsQuery() is not implemented');
  }

  Future<News> getNews(String newsId, {String? newsTenantId}) async {
    throw UnimplementedError('getNews() is not implemented');
  }

  Future<void> readNews(String userAccessToken, String newsId,
      {String? newsTenantId}) async {
    throw UnimplementedError('readNews() is not implemented');
  }

  Future<void> addNewsToFavorite(String userAccessToken, String newsId,
      {String? newsTenantId}) async {
    throw UnimplementedError('addNewsToFavorite() is not implemented');
  }

  Future<void> deleteNewsFromFavorite(String userAccessToken, String newsId,
      {String? newsTenantId}) async {
    throw UnimplementedError('deleteNewsFromFavorite() is not implemented');
  }

  // Beacon Client

  BeaconQueryPlatform beaconQuery() {
    throw UnimplementedError('beaconQuery() is not implemented');
  }

  BeaconContactQueryPlatform beaconContactQuery(String userAccessToken) {
    throw UnimplementedError('beaconContactQuery() is not implemented');
  }

  SpotQueryPlatform spotQuery() {
    throw UnimplementedError('spotQuery() is not implemented');
  }

  Future<void> addBeaconContact(String userAccessToken,
      {required DateTime contactDate,
      required String beaconId,
      String? beaconSpotCd,
      int? rssi,
      String? remarks}) async {
    throw UnimplementedError('addBeaconContact() is not implemented');
  }

  // Coupon Client

  CouponQueryPlatform couponQuery() {
    throw UnimplementedError('couponQuery() is not implemented');
  }

  Future<Coupon> getCoupon(String code) async {
    throw UnimplementedError('getCoupon() is not implemented');
  }

  Future<void> exchangeCoupon(
      String userAccessToken, String code, int quantity) async {
    throw UnimplementedError('exchangeCoupon() is not implemented');
  }

  MyCouponQueryPlatform myCouponQuery(String userAccessToken) {
    throw UnimplementedError('myCouponQuery() is not implemented');
  }

  Future<MyCoupon> getMyCoupon(
      String userAccessToken, String myCouponCd) async {
    throw UnimplementedError('getMyCoupon() is not implemented');
  }

  Future<void> useMyCoupon(
      String userAccessToken, String myCouponCd, String couponCd) async {
    throw UnimplementedError('useMyCoupon() is not implemented');
  }

  // Point Client

  Future<Point> getPoint(String userAccessToken) async {
    throw UnimplementedError('getPoint() is not implemented');
  }

  Future<Point> addPoint(String userAccessToken, int point,
      {DateTime? addedDate}) async {
    throw UnimplementedError('addPoint() is not implemented');
  }

  // Stamp Client

  StampRallyQueryPlatform stampRallyQuery() {
    throw UnimplementedError('stampRallyQuery() is not implemented');
  }

  StampRallySpotQueryPlatform stampRallySpotQuery() {
    throw UnimplementedError('stampRallySpotQuery() is not implemented');
  }

  Future<void> completeStampRally(
      String userAccessToken, String stampRallyId) async {
    throw UnimplementedError('completeStampRally() is not implemented');
  }

  Future<void> addStampHistory(String userAccessToken, String stampRallyId,
      String stampRallySpotCd) async {
    throw UnimplementedError('addStampHistory() is not implemented');
  }

  StampHistoryQueryPlatform stampHistoryQuery(String userAccessToken) {
    throw UnimplementedError('stampHistoryQuery() is not implemented');
  }

  // UserDetail Client

  UserDetailQueryPlatform userDetailQuery(String objectId,
      {String? userAccessToken}) {
    throw UnimplementedError('userDetailQuery() is not implemented');
  }

  Future<UserDetail> addUserDetail(
      String userAccessToken, UserDetail userDetail) async {
    throw UnimplementedError('addUserDetail() is not implemented');
  }

  Future<UserDetail> editUserDetail(
      String userAccessToken, UserDetail userDetail) async {
    throw UnimplementedError('editUserDetail() is not implemented');
  }

  Future<void> addUserDetailToFavorite(
      String userAccessToken, String objectId, String id) async {
    throw UnimplementedError('addUserDetailToFavorite() is not implemented');
  }

  Future<void> deleteUserDetailFromFavorite(
      String userAccessToken, String objectId, String id) async {
    throw UnimplementedError(
        'deleteUserDetailFromFavorite() is not implemented');
  }
}
