/// デバイス区分(iOSまたはAndroid)です。
enum DeviceType {
  /// iOS
  ios,

  /// Android
  android,
}

/// ユーザー詳細の公開範囲です。
enum VisibilityType {
  /// 非公開
  ///
  /// この公開範囲を指定したユーザー詳細は、登録したユーザーのみ参照することができます。
  private,

  /// 公開(制限付き)
  ///
  /// この公開範囲を指定したユーザー詳細は、登録したユーザー以外も参照することができます。
  /// ただし、参照するにはユーザーアクセストークンで認証を行う必要があります。
  publicToUsers,

  /// 公開
  ///
  /// この公開範囲を指定したユーザー詳細は、登録したユーザー以外も参照することができます。
  /// [publicToUsers]と異なり、参照にユーザーアクセストークンは不要です。
  public,
}

extension VisibilityTypeExtensions on VisibilityType {
  /// テキストに変換します。
  String? toStringValue() {
    switch (this) {
      case VisibilityType.private:
        return '0001';
      case VisibilityType.publicToUsers:
        return '0002';
      case VisibilityType.public:
        return '0003';
      default:
        return null;
    }
  }
}

class ReadHistoryType {
  static const alreadyRead = '0001';
  static const unread = '0002';
}

/// BaaS@rakuzaのAPIが返すステータスの定数です。
class RKZStatus {
  /// 正常
  static const ok = '1001';

  /// バリデーションエラー
  static const errorValidation = '2001';

  /// アクションエラー
  static const errorAction = '2002';

  /// 未ログインエラー
  static const errorUnlogged = '2003';

  /// 排他エラー
  static const errorExclusion = '2004';

  /// 認証エラー
  static const errorAuthentication = '9001';

  /// システムエラー
  static const errorSystem = '9002';

  /// データベース接続エラー
  static const errorDatabaseConnection = '9003';

  /// メール送信エラー(SMTPエラー)
  static const errorMailSendingSMTP = '9004';

  /// メール送信エラー
  static const errorMailSending = '9005';

  /// 機能権限エラー
  static const errorFunctionAuthority = '9006';

  /// アクセストークン不正
  static const errorInvalidAccessToken = '9007';

  /// API整合性エラー
  static const errorMismatch = '9011';

  /// 初期化エラー
  static const errorInitialization = '9012';

  /// 必須入力チェックエラー
  static const errorParamRequired = '9020';

  /// HTTPエラー
  static const errorHTTP = '9030';

  /// タイムアウトエラー
  static const errorTimeout = '9031';
}
