import '../file.dart';
import '../models/order.dart';
import '../types.dart';

DateTime? importDate(int? time) {
  if (time == null) return null;
  return DateTime.fromMillisecondsSinceEpoch(time);
}

bool? importBool(String? value) {
  if (value == null) return null;
  return value == '1';
}

Map<String, dynamic>? importMap(Map? otherMap) {
  if (otherMap == null) return null;
  return Map<String, dynamic>.from(otherMap);
}

List<String>? importStringList(List<dynamic>? dynamicList) {
  if (dynamicList == null) return null;
  return dynamicList.cast<String>().toList();
}

VisibilityType? importVisibility(String? value) {
  if (value == null) return null;

  switch (value) {
    case '0001':
      return VisibilityType.private;
    case '0002':
      return VisibilityType.publicToUsers;
    case '0003':
      return VisibilityType.public;
    default:
      return null;
  }
}

int? exportDate(DateTime? dateTime) {
  return dateTime?.millisecondsSinceEpoch;
}

String? exportBool(bool? value) {
  if (value == null) return null;
  return value ? '1' : '0';
}

String? exportDirection(Direction? direction) {
  if (direction == null) return null;
  return direction.toStringValue();
}

Map<String, dynamic>? exportAttributes(Map<String, dynamic>? value) {
  if (value == null) return null;

  return value.map<String, dynamic>((key, dynamic value) =>
      MapEntry<String, dynamic>(key, _exportValue(value)));
}

dynamic _exportValue(dynamic value) {
  if (value == null) return null;

  if (value is RKZFile) {
    return value.toMap();
  }
  return value;
}
